@@ -1,3 +1,4 @@
+from fsds2021.imports import global_imports,import_packages
 
 def ihelp(function_or_mod, show_help=False, show_code=True,return_code=False,markdown=True,file_location=False):
     """Call on any module or functon to display the object's
@@ -5,10 +6,10 @@ def ihelp(function_or_mod, show_help=False, show_code=True,return_code=False,mar
     using Python-syntax"""
     import inspect
     
-    try:
-        from IPython.display import display, Markdown
-    except:
-        print('[!] IPython was not found.')
+    # try:
+    from IPython.display import display, Markdown
+    # except:
+        # print('[!] IPython was not found.')
         
     page_header = '---'*28
     # footer = '---'*28+'\n'
@@ -23,6 +24,8 @@ def ihelp(function_or_mod, show_help=False, show_code=True,return_code=False,mar
     if "google.colab" in sys.modules:
         markdown=False
 
+    ## Initialize source df
+    source_DF = None
     if show_code:
         print(page_header)
 
@@ -378,6 +381,7 @@ show_how_to_delete=False,print_names=False):
     var_list = [x for x in var_list if (x.startswith('_') == False) and (x not in exclude)]
 
     i=0
+    real_var = None
     for var in var_list:#globals().items():#locals().items():
 
         if var in loc_vars:
@@ -832,6 +836,7 @@ def save_ihelp_to_file(function,save_help=False,save_code=True,
     else:
         save_filename = folder+filename
 
+    ext = '.'
     if as_md:
         ext = '.md'
     elif as_txt:
